SWDEV-491257 - Create stream capture tests with Event APIs
Change-Id: I9803a78c3513845f7bf91333a0db0d43bed5b346
[ROCm/hip-tests commit: fd92c47fea]
This commit is contained in:
کامیت شده توسط
Rakesh Roy
والد
182d514c0d
کامیت
aee10912e0
@@ -151,6 +151,24 @@ TEST_CASE("Unit_hipEventDestroy_Negative") {
|
||||
}
|
||||
#endif
|
||||
|
||||
TEST_CASE("Unit_hipEventDestroy_Verify_Capture") {
|
||||
hipEvent_t event;
|
||||
HIP_CHECK(hipEventCreate(&event));
|
||||
REQUIRE(event != nullptr);
|
||||
|
||||
hipStream_t stream;
|
||||
HIP_CHECK(hipStreamCreate(&stream));
|
||||
hipStreamCaptureMode mode = GENERATE(hipStreamCaptureModeGlobal, hipStreamCaptureModeThreadLocal,
|
||||
hipStreamCaptureModeRelaxed);
|
||||
HIP_CHECK(hipStreamBeginCapture(stream, mode));
|
||||
HIP_CHECK(hipEventDestroy(event));
|
||||
hipGraph_t graph;
|
||||
HIP_CHECK(hipStreamEndCapture(stream, &graph));
|
||||
|
||||
HIP_CHECK(hipGraphDestroy(graph));
|
||||
HIP_CHECK(hipStreamDestroy(stream));
|
||||
}
|
||||
|
||||
/**
|
||||
* End doxygen group EventTest.
|
||||
* @}
|
||||
|
||||
مرجع در شماره جدید
Block a user